==> 1.0.0-dev.1.tar.gz: lib/src/agent/http/dns_info.dart <==
import 'dart:core';
import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:tingyun_flutter_plugin/src/agent/util/logger.dart';
import 'package:tingyun_flutter_plugin/src/agent/util/string_utils.dart';

class DnsInfo {

  static Map<String, DnsInfo> _dnsInfoMap = Map();

  String _hostName;
  String _ipAddress;
  int _dnsDuration;
  bool _isUsed;

  DnsInfo(this._hostName, this._ipAddress, this._dnsDuration){
    this._isUsed = false;
  }

  // String get hostName => _hostName;
  //
  // String get ipAddress => _ipAddress;
  //
  // int get dnsDuration => _dnsDuration;

  bool _isDnsAvalid() {
    //dnsTime小于或者等于这个阈值，算是复用dns吧，所以就不设置
    if (_dnsDuration >= 2) {
      return true;
    }
    return false;
  }
  
  static void addDnsInfoToMap(String key, DnsInfo dnsInfo){
    if(!StringUtils.isStringNullOrEmpty(key) && !_dnsInfoMap.containsKey(key)
        && dnsInfo != null && dnsInfo._isDnsAvalid()){
      Logger().d("addDnsInfoToMap key:$key, dnstime:${dnsInfo._dnsDuration}");
      _dnsInfoMap.putIfAbsent(key, () => dnsInfo);
    }
  }

  static bool isKeyExist(String key){
    if(_dnsInfoMap.containsKey(key)){
      return true;
    }
    return false;
  }

  static String getIpAddress(String key){
    if(isKeyExist(key)){
      return _dnsInfoMap[key]._ipAddress;
    }
    return "";
  }

  static int getDnsDuration(String key){
    if(isKeyExist(key)){
      if(_dnsInfoMap[key]._isUsed){
        return 0;
      }
      Logger().d("getDnsDuration key:$key, dnstime:${_dnsInfoMap[key]._dnsDuration}");
      _dnsInfoMap[key]._isUsed = true;
      return _dnsInfoMap[key]._dnsDuration;
    }
    return 0;
  }

  static void setDnsInfo(String hostUri) async{
    try {
      if(isKeyExist(hostUri)){
        return;
      }

      /// 获取dns的时间？
      int beginTime = DateTime
          .now()
          .millisecondsSinceEpoch;
      List<InternetAddress> addressInfo = await InternetAddress.lookup(
          hostUri);
      int dnsTime = DateTime
          .now()
          .millisecondsSinceEpoch - beginTime;
      String ipInfo = "";
      if (addressInfo != null && addressInfo.length > 0) {
        ipInfo = addressInfo[0].address;
      }
      Logger().d('_dnsDuration:$dnsTime, _ipInfo:$ipInfo');

      addDnsInfoToMap(hostUri, DnsInfo(hostUri, ipInfo, dnsTime));
    }catch(e){
      Logger().d('error setDnsInfo:$e');
    }
  }

  @visibleForTesting
  static int getMaplength(){
    return _dnsInfoMap.length;
  }
}

==> 2.1.0.tar.gz: lib/src/agent/http/dns_info.dart <==
import 'dart:core';
import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:tingyun_flutter_plugin/src/agent/util/logger.dart';
import 'package:tingyun_flutter_plugin/src/agent/util/string_utils.dart';

class DnsInfo {

  static Map<String, DnsInfo> _dnsInfoMap = Map();

  String _hostName;
  String _ipAddress;
  int _dnsDuration;
  late bool _isUsed;

  DnsInfo(this._hostName, this._ipAddress, this._dnsDuration){
    this._isUsed = false;
  }

  // String get hostName => _hostName;
  //
  // String get ipAddress => _ipAddress;
  //
  // int get dnsDuration => _dnsDuration;

  bool _isDnsAvalid() {
    //dnsTime小于或者等于这个阈值，算是复用dns吧，所以就不设置
    if (_dnsDuration >= 2) {
      return true;
    }
    return false;
  }
  
  static void addDnsInfoToMap(String key, DnsInfo dnsInfo){
    if(!StringUtils.isStringNullOrEmpty(key) && !_dnsInfoMap.containsKey(key)
        && dnsInfo != null && dnsInfo._isDnsAvalid()){
      Logger().d("addDnsInfoToMap key:$key, dnstime:${dnsInfo._dnsDuration}");
      _dnsInfoMap.putIfAbsent(key, () => dnsInfo);
    }
  }

  static bool isKeyExist(String key){
    if(_dnsInfoMap.containsKey(key)){
      return true;
    }
    return false;
  }

  static String getIpAddress(String key){
    if(isKeyExist(key)){
      return _dnsInfoMap[key]!._ipAddress;
    }
    return "";
  }

  static int getDnsDuration(String key){
    if(isKeyExist(key)){
      if(_dnsInfoMap[key]!._isUsed){
        return 0;
      }
      Logger().d("getDnsDuration key:$key, dnstime:${_dnsInfoMap[key]!._dnsDuration}");
      _dnsInfoMap[key]!._isUsed = true;
      return _dnsInfoMap[key]!._dnsDuration;
    }
    return 0;
  }

  static void setDnsInfo(String hostUri) async{
    try {
      if(isKeyExist(hostUri)){
        return;
      }

      /// 获取dns的时间？
      int beginTime = DateTime
          .now()
          .millisecondsSinceEpoch;
      List<InternetAddress> addressInfo = await InternetAddress.lookup(
          hostUri);
      int dnsTime = DateTime
          .now()
          .millisecondsSinceEpoch - beginTime;
      String ipInfo = "";
      if (addressInfo != null && addressInfo.length > 0) {
        ipInfo = addressInfo[0].address;
      }
      Logger().d('_dnsDuration:$dnsTime, _ipInfo:$ipInfo');

      addDnsInfoToMap(hostUri, DnsInfo(hostUri, ipInfo, dnsTime));
    }catch(e){
      Logger().d('error setDnsInfo:$e');
    }
  }

  @visibleForTesting
  static int getMaplength(){
    return _dnsInfoMap.length;
  }
}
